# Changelog

## [0.1.1](https://github.com/uptick/otel-ci/compare/v0.1.0...v0.1.1) (2024-12-14)


### Bug Fixes

* modify ci pipeline ([a3f9b4b](https://github.com/uptick/otel-ci/commit/a3f9b4b1b4972249886c0f446661063a1b83e721))

## 0.1.0 (2024-12-14)


### Features

* add ci pipelines and fix broken resource attributes ([31812da](https://github.com/uptick/otel-ci/commit/31812da23959e666f21eac33af92ba5eb6775fdd))
